@@ -1,10 +1,10 @@
 import json
 
-import vogeler.log as logger
+import vogeler.logger as logger
 import vogeler.exceptions as exceptions
+import vogeler.conf as conf
 from vogeler.messaging import amqp
 
-log = logger.setup_logger(logLevel='DEBUG', logFile=None, name='vogeler-client')
 
 class VogelerClient(object):
     """
@@ -24,16 +24,43 @@ class VogelerClient(object):
 
         an instance of :class:`amqplib.client_0_8.channel.Queue`
 
-    :raises: :class:`vogeler.exceptions.VogelerClientException`
+    :raises: :class:`vogeler.exceptions.VogelerClientConnectionException`
 
     """
     def __init__(self, callback_function=None, **kwargs):
+
+        self._configured = False
+
+        if kwargs.has_key("config"):
+            self._configure(kwargs["config"])
+            self._configured = True
+
+        if kwargs.has_key("loglevel"):
+            log_level = kwargs["loglevel"]
+        elif self._configured is True and self._config.has_option('global', 'log_level'):
+            log_level = self._config.get('global', 'log_level')
+        else:
+            log_level = 'WARN'
+
+        self.log = logger.LogWrapper(name='vogeler-client', level=log_level).logger()
+
+        if kwargs.has_key("dsn"):
+            _dsn = kwargs["dsn"]
+        elif self._configured is True and self._config.has_option('amqp', 'dsn'):
+            _dsn = self._config.get('amqp', 'dsn')
+        else:
+            self.log.fatal("No dsn provided. Cannot continue")
+
         try:
-            self.ch, self.queue = amqp.setup_client(kwargs['host'], kwargs['username'], kwargs['password'])
+            self.ch, self.queue = amqp.setup_client(_dsn)
             self.callback_function = callback_function
-        except:
-            log.fatal("Error connecting to %s as %s" % (kwargs['host'], kwargs['username']))
-            raise exceptions.VogelerClientConnectionException()
+        except Exception, e:
+            self.log.fatal("Error connecting to %s" % _dsn)
+            raise exceptions.VogelerClientConnectionException(e)
+
+    def _configure(self, config_file=None):
+        if config_file is not None:
+            self._config = conf.configure(cfg=config_file)
 
     def callback(self, msg):
         """
@@ -43,11 +70,13 @@ class VogelerClient(object):
         :param msg: Instance of :class:`amqplib.client_0_8.basic_message.Message`
 
         """
+        self.log.info("Message recieved")
         try:
             message = json.loads(msg.body)
-        except:
-            log.warn("Message not in JSON format")
-            raise exceptions.VogelerClientPluginException()
+            self.log.info("Message decoded")
+        except Exception, e:
+            self.log.warn("Message not in JSON format")
+            raise exceptions.VogelerClientPluginException(e)
 
         if(self.callback_function):
             self.callback_function(message)
@@ -59,11 +88,12 @@ class VogelerClient(object):
         :raises: :class:`vogeler.exceptions.VogelerClientException`
         """
         try:
-            log.info("Vogeler(Client) is starting up")
+            self.log.info("Vogeler(Client) is starting up")
             self.ch.basic_consume(self.queue, callback=self.callback, no_ack=True)
-        except:
-            log.fatal("Error Consuming queue")
-            raise exceptions.VogelerClientConnectionException()
+            self.log.info("Vogeler(Client) has started")
+        except Exception, e:
+            self.log.fatal("Error Consuming queue")
+            raise exceptions.VogelerClientConnectionException(e)
 
         while self.ch.callbacks:
             self.ch.wait()
@@ -83,19 +113,20 @@ class VogelerClient(object):
         :raises: :class:`vogeler.exceptions.VogelerClientException`
 
         """
-        log.info("Vogeler(Client) is sending a message")
         try:
+            self.log.debug("Vogeler(Client) is sending a message")
             msg = amqp.amqp.Message(json.dumps(message))
             if durable == True:
                 msg.properties['delivery_mode'] = 2
             self.ch.basic_publish(msg, exchange=amqp.master_exchange)
-        except:
-            log.fatal("Error publishing message to the queue")
-            raise exceptions.VogelerClientConnectionException()
+            self.log.debug("Vogeler(Client) finished sending message")
+        except Exception, e:
+            self.log.fatal("Error publishing message to the queue")
+            raise exceptions.VogelerClientConnectionException(e)
 
     def close(self):
         """Close the channel with the broker"""
-        log.info("Closing channel")
+        self.log.info("Closing channel")
         self.ch.close()
 
 # vim: set ts=4 et sw=4 sts=4 sta filetype=python :
